---
title: '[공지] 포트원 관리자콘솔 간헐적 로딩오류 공지(조치완료)'
category: 공지사항
tags:
  - 공통
  - 공지사항
datetime: 2023-11-19T15:00:00.000Z
---

안녕하세요, 포트원 고객지원팀입니다.

금일(2023-11-21) 포트원 관리자콘솔의 홈 화면과 애널리틱스 화면이 일시적으로 보이지 않는 오류가 있었으며,당사에서 긴급 확인 후 조치완료되어 공지드립니다.

(본 이슈는 포트원의 결제와는 무관한 이슈로 결제서비스에는 영향이 없습니다)

이용에 불편을 드리게 되어 대단히 죄송합니다.

원활한 서비스 제공을 위해 최선을 다하도록 하겠습니다.

---

#### 상세

- 영향: 관리자콘솔 간헐적 로딩 오류
- 장애시각: 2023.11.21(화) 08:08 \~ 10:26
- 대응 : 긴급 조치완료

---

감사합니다.

포트원(PortOne) 드림
